IMPORTANT DEFINITION OF TESTS IN CINDER
=======================================

Cinder has a number of different test types, PLEASE be sure to refer
to the Cinder Testing Docs to familiarize yourself with the various
options before creating any new tests.

Please check `Cinder-Testing <https://docs.openstack.org/cinder/latest/contributor/testing.html>`_.
